@@ -22,11 +22,12 @@
 # THE SOFTWARE.
 #
 import logging
-log = logging.getLogger(__name__)
-log.addHandler(logging.NullHandler())
 
 from .adapter import Adapter, FakeAdapter
 
+log = logging.getLogger(__name__)
+log.addHandler(logging.NullHandler())
+
 try:
     from pymeasure.adapters.visa import VISAAdapter
 except ImportError:
@@ -37,3 +38,8 @@ try:
     from pymeasure.adapters.prologix import PrologixAdapter
 except ImportError:
     log.warning("PySerial library could not be loaded")
+
+try:
+    from pymeasure.adapters.vxi11 import VXI11Adapter
+except ImportError:
+    log.warning("VXI-11 library could not be loaded")
