@@ -23,22 +23,26 @@
 #
 
 import logging
+
+import sys
+import time
+
+from .Qt import QtGui
+from .windows import PlotterWindow
+from ..thread import StoppableThread
+
 log = logging.getLogger(__name__)
 log.addHandler(logging.NullHandler())
 
-from .Qt import QtGui
 
-from ..process import StoppableProcess
-from .windows import PlotterWindow
-
-import sys
-from time import sleep
-import pyqtgraph as pg
-
-
-class Plotter(StoppableProcess):
+class Plotter(StoppableThread):
     """ Plotter dynamically plots data from a file through the Results
     object and supports error bars.
+
+    .. seealso::
+
+        Tutorial :ref:`tutorial-plotterwindow`
+            A tutorial and example on using the Plotter and PlotterWindow.
     """
 
     def __init__(self, results, refresh_time=0.1):
@@ -49,10 +53,23 @@ class Plotter(StoppableProcess):
     def run(self):
         app = QtGui.QApplication(sys.argv)
         window = PlotterWindow(self, refresh_time=self.refresh_time)
+        self.setup_plot(window.plot)
         app.aboutToQuit.connect(window.quit)
         window.show()
         app.exec_()
 
+    def setup_plot(self, plot):
+        """
+        This method does nothing by default, but can be overridden by the child
+        class in order to set up custom options for the plot window, via its
+        PlotItem_.
+
+        :param plot: This window's PlotItem_ instance.
+
+        .. _PlotItem: http://www.pyqtgraph.org/documentation/graphicsItems/plotitem.html
+        """
+        pass
+
     def wait_for_close(self, check_time=0.1):
         while not self.should_stop():
-            sleep(check_time)
+            time.sleep(check_time)
