@@ -26,6 +26,9 @@ import logging
 
 import os
 import re
+import sys
+from copy import deepcopy
+from importlib.machinery import SourceFileLoader
 from datetime import datetime
 
 import pandas as pd
@@ -61,6 +64,34 @@ def unique_filename(directory, prefix='DATA', suffix='', ext='csv',
     return filename
 
 
+class CSVFormatter(logging.Formatter):
+    """ Formatter of data results """
+
+    def __init__(self, columns, delimiter=','):
+        """Creates a csv formatter for a given list of columns (=header).
+
+        :param columns: list of column names.
+        :type columns: list
+        :param delimiter: delimiter between columns.
+        :type delimiter: str
+        """
+        super().__init__()
+        self.columns = columns
+        self.delimiter = delimiter
+
+    def format(self, record):
+        """Formats a record as csv.
+
+        :param record: record to format.
+        :type record: dict
+        :return: a string
+        """
+        return self.delimiter.join('{}'.format(record[x]) for x in self.columns)
+
+    def format_header(self):
+        return self.delimiter.join(self.columns)
+
+
 class Results(object):
     """ The Results class provides a convenient interface to reading and
     writing data in connection with a :class:`.Procedure` object.
@@ -88,6 +119,8 @@ class Results(object):
         self.parameters = procedure.parameter_objects()
         self._header_count = -1
 
+        self.formatter = CSVFormatter(columns=self.procedure.DATA_COLUMNS)
+
         if isinstance(data_filename, (list, tuple)):
             data_filenames, data_filename = data_filename, data_filename[0]
         else:
@@ -107,6 +140,39 @@ class Results(object):
                     f.write(self.labels())
             self._data = None
 
+    def __getstate__(self):
+        # Get all information needed to reconstruct procedure
+        self._parameters = self.procedure.parameter_values()
+        self._class = self.procedure.__class__.__name__
+        module = sys.modules[self.procedure.__module__]
+        self._package = module.__package__
+        self._module = module.__name__
+        self._file = module.__file__
+
+        state = self.__dict__.copy()
+        del state['procedure']
+        del state['procedure_class']
+        return state
+
+    def __setstate__(self, state):
+        self.__dict__.update(state)
+
+        # Restore the procedure
+        module = SourceFileLoader(self._module, self._file).load_module()
+        cls = getattr(module, self._class)
+
+        self.procedure = cls()
+        self.procedure.set_parameters(self._parameters)
+        self.procedure.refresh_parameters()
+
+        self.procedure_class = cls
+
+        del self._parameters
+        del self._class
+        del self._package
+        del self._module
+        del self._file
+
     def header(self):
         """ Returns a text header to accompany a datafile so that the procedure
         can be reconstructed
@@ -127,15 +193,13 @@ class Results(object):
         """ Returns the columns labels as a string to be written
         to the file
         """
-        return (Results.DELIMITER.join(self.procedure.DATA_COLUMNS) +
-                Results.LINE_BREAK)
+        return self.formatter.format_header() + Results.LINE_BREAK
 
     def format(self, data):
         """ Returns a formatted string containing the data to be written
         to a file
         """
-        rows = [str(data[x]) for x in self.procedure.DATA_COLUMNS]
-        return Results.DELIMITER.join(rows) + Results.LINE_BREAK
+        return self.formatter.format(data)
 
     def parse(self, line):
         """ Returns a dictionary containing the data from the line """
@@ -145,7 +209,8 @@ class Results(object):
             data[key] = items[i]
         return data
 
-    def parse_header(self, header, procedure_class=None):
+    @staticmethod
+    def parse_header(header, procedure_class=None):
         """ Returns a Procedure object with the parameters as defined in the
         header text.
         """
@@ -189,7 +254,7 @@ class Results(object):
                 procedure = procedure_class()
             except ImportError:
                 procedure = UnknownProcedure(parameters)
-                log.warning("Unknown Procedure in %s" % self.data_filename)
+                log.warning("Unknown Procedure being used")
             except Exception as e:
                 raise e
 
@@ -248,7 +313,7 @@ class Results(object):
             except Exception:
                 # Empty dataframe
                 self._data = pd.DataFrame(columns=self.procedure.DATA_COLUMNS)
-        else:  # Concatenate additional data
+        else:  # Concatenate additional data, if any, to already loaded data
             skiprows = len(self._data) + self._header_count
             chunks = pd.read_csv(
                 self.data_filename,
@@ -259,8 +324,13 @@ class Results(object):
             )
             try:
                 tmp_frame = pd.concat(chunks, ignore_index=True)
-                self._data = pd.concat([self._data, tmp_frame],
-                                       ignore_index=True)
+                # only append new data if there is any
+                # if no new data, tmp_frame dtype is object, which override's
+                # self._data's original dtype - this can cause problems plotting
+                # (e.g. if trying to plot int data on a log axis)
+                if len(tmp_frame) > 0:
+                    self._data = pd.concat([self._data, tmp_frame],
+                                           ignore_index=True)
             except Exception:
                 pass  # All data is up to date
         return self._data
@@ -279,3 +349,10 @@ class Results(object):
             self._data = pd.concat(chunks, ignore_index=True)
         except Exception:
             self._data = chunks.read()
+
+    def __repr__(self):
+        return "<{}(filename='{}',procedure={},shape={})>".format(
+            self.__class__.__name__, self.data_filename,
+            self.procedure.__class__.__name__,
+            self.data.shape
+        )
