@@ -1,7 +1,7 @@
 #
 # This file is part of the PyMeasure package.
 #
-# Copyright (c) 2013-2016 PyMeasure Developers
+# Copyright (c) 2013-2017 PyMeasure Developers
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -48,7 +48,7 @@ class Keithley2400(Instrument, KeithleyBuffer):
         
         keithley.apply_current()                # Sets up to source current
         keithley.source_current_range = 10e-3   # Sets the source current range to 10 mA
-        keithley.compliance_voltage = 10        # Sets the complinance voltage to 10 V
+        keithley.compliance_voltage = 10        # Sets the compliance voltage to 10 V
         keithley.source_current = 0             # Sets the source current to 0 mA
         keithley.enable_source()                # Enables the source output
 
@@ -348,8 +348,8 @@ class Keithley2400(Instrument, KeithleyBuffer):
         The compliance current is also set.
 
         :param compliance_current: A float in the correct range for a 
-                                   :attr:`~.compliance_current`
-        :param voltage_range: A :attr:`~.voltage_range` value or None
+                                   :attr:`~.Keithley2400.compliance_current`
+        :param voltage_range: A :attr:`~.Keithley2400.voltage_range` value or None
         """
         log.info("%s is sourcing voltage." % self.name)
         self.source_mode = 'voltage'
@@ -357,7 +357,7 @@ class Keithley2400(Instrument, KeithleyBuffer):
             self.auto_range_source()
         else:
             self.source_voltage_range = voltage_range
-        self.compliance_current = complinance_current
+        self.compliance_current = compliance_current
         self.check_errors()
 
     def beep(self, frequency, duration):
@@ -454,7 +454,7 @@ class Keithley2400(Instrument, KeithleyBuffer):
 
     def trigger_on_bus(self):
         """ Configures the trigger to detect events based on the bus
-        trigger, which can be activated by GET or *TRG.
+        trigger, which can be activated by :code:`GET` or :code:`*TRG`.
         """
         self.write(":ARM:COUN 1;:ARM:SOUR BUS;:TRIG:SOUR BUS;")
 
@@ -548,7 +548,7 @@ class Keithley2400(Instrument, KeithleyBuffer):
     @property
     def min_current(self):
         """ Returns the minimum current from the buffer """
-        return self.mininums[1]
+        return self.minimums[1]
 
     @property
     def std_current(self):
